@@ -162,9 +162,7 @@ Arch: all
 
 class DummyFixer(Fixer):
 
-    def run(self, basedir, package, current_version, compat_release,
-            minimum_certainty, trust_package, allow_reformatting, net_access,
-            opinionated):
+    def run(self, basedir, package, *args, **kwargs):
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
             f.write('a new line\n')
         return FixerResult("Fixed some tag.\nExtended description.",
@@ -173,9 +171,7 @@ class DummyFixer(Fixer):
 
 class FailingFixer(Fixer):
 
-    def run(self, basedir, package, current_version, compat_release,
-            minimum_certainty, trust_package, allow_reformatting, net_access,
-            opinionated):
+    def run(self, basedir, package, *args, **kwargs):
         with open(os.path.join(basedir, 'debian/foo'), 'w') as f:
             f.write("blah")
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
@@ -232,9 +228,7 @@ Arch: all
         tree = self.make_test_tree()
 
         class UncertainFixer(Fixer):
-            def run(self, basedir, package, current_version, compat_release,
-                    minimum_certainty, trust_package, allow_reformatting,
-                    net_access, opinionated):
+            def run(self, basedir, package, *args, **kwargs):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -249,9 +243,7 @@ Arch: all
         tree = self.make_test_tree()
 
         class UncertainFixer(Fixer):
-            def run(self, basedir, package, current_version, compat_release,
-                    minimum_certainty, trust_package, allow_reformatting,
-                    net_access, opinionated):
+            def run(self, basedir, package, *args, **kwargs):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -265,9 +257,7 @@ Arch: all
         tree = self.make_test_tree()
 
         class NewFileFixer(Fixer):
-            def run(self, basedir, package, current_version, compat_release,
-                    minimum_certainty, trust_package, allow_reformatting,
-                    net_access, opinionated):
+            def run(self, basedir, package, *args, **kwargs):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Created new file.", ['some-tag'])
@@ -296,9 +286,7 @@ Arch: all
         tree = self.make_test_tree()
 
         class RenameFileFixer(Fixer):
-            def run(self, basedir, package, current_version, compat_release,
-                    minimum_certainty, trust_package, allow_reformatting,
-                    net_access, opinionated):
+            def run(self, basedir, package, *args, **kwargs):
                 os.rename(os.path.join(basedir, 'debian/control'),
                           os.path.join(basedir, 'debian/control.blah'))
                 return FixerResult("Renamed a file.")
@@ -326,9 +314,7 @@ Arch: all
         tree = self.make_test_tree()
 
         class EmptyFixer(Fixer):
-            def run(self, basedir, package, current_version, compat_release,
-                    minimum_certainty, trust_package, allow_reformatting,
-                    net_access, opinionated):
+            def run(self, basedir, package, *args, **kwargs):
                 return FixerResult("I didn't actually change anything.")
         with tree.lock_write():
             self.assertRaises(
@@ -511,8 +497,11 @@ blah (0.1) unstable; urgency=medium
 
     def test_no_changes(self):
         tree = self.make_package_tree()
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
     def test_other_change(self):
         tree = self.make_package_tree()
@@ -526,9 +515,11 @@ Binary: blah
 Arch: all
 
 """)])
-
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
     def test_other_changes(self):
         tree = self.make_package_tree()
@@ -550,8 +541,11 @@ blah (0.1) UNRELEASED; urgency=medium
 
  -- Blah <example@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
 """)])
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
     def test_changes_to_other_changelog_entries(self):
         tree = self.make_package_tree()
@@ -569,8 +563,11 @@ blah (0.1) unstable; urgency=medium
 
  -- Blah <example@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
 """)])
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
     def test_changes_to_last_only(self):
         tree = self.make_package_tree()
@@ -589,8 +586,11 @@ blah (0.1) unstable; urgency=medium
 
  -- Blah <example@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
 """)])
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertTrue(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
     def test_changes_to_last_only_but_released(self):
         tree = self.make_package_tree()
@@ -624,8 +624,11 @@ blah (0.1) unstable; urgency=medium
 
  -- Blah <example@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
 """)])
+        basis_tree = tree.basis_tree()
+        with tree.lock_read(), basis_tree.lock_read():
+            changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog'))
+            tree, 'debian/changelog', changes))
 
 
 class LintianBrushVersion(TestCase):
@@ -764,6 +767,16 @@ Do bla
 Fixed-Lintian-Tags: tag-a
 """))
 
+    def test_patch_name(self):
+        self.assertEqual(
+            FixerResult('Do bla', ['tag-a'], 'certain', 'aname'),
+            parse_script_fixer_output("""\
+Do bla
+Fixed-Lintian-Tags: tag-a
+Certainty: certain
+Patch-Name: aname
+"""))
+
 
 class BaseScriptFixerTests(object):
 
